@@ -1,8 +1,10 @@
 from .bitcoin import *
 from .bitcoin_cash import *
 from .bitcoin_gold import *
+from .counterparty import *
 from .dash import *
 from .dogecoin import *
 from .ethereum import *
 from .ethereum_forks import *
 from .litecoin import *
+from .unsupported_coin import *
\ No newline at end of file
