@@ -38,7 +38,7 @@ class BitcoinCash(BaseCoin):
         Get address from a public key
         """
         #addr_legacy= super(BitcoinCash, self).pubtoaddr(pubkey, magicbyte=self.magicbyte)
-        addr_legacy= super().pubtoaddr(pubkey)
+        addr_legacy= super().pubtolegacy(pubkey)
         print("ADDR_LEGACY: "+addr_legacy)
         addr= convert.to_cash_address(addr_legacy) #cashAddr conversion
         
